[gtk+/rendering-cleanup: 20/63] gdk: Use the system colormap, not the rgb colormap



commit 7494c380d5675aa47ce753c6a78b45718c771237
Author: Benjamin Otte <otte redhat com>
Date:   Tue Jul 13 02:47:04 2010 +0200

    gdk: Use the system colormap, not the rgb colormap
    
    RGB colormaps are on their way out.

 gdk/gdkpixbuf-render.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gdk/gdkpixbuf-render.c b/gdk/gdkpixbuf-render.c
index 776dd2d..4504390 100644
--- a/gdk/gdkpixbuf-render.c
+++ b/gdk/gdkpixbuf-render.c
@@ -150,7 +150,7 @@ gdk_pixbuf_render_threshold_alpha (GdkPixbuf *pixbuf,
  * given drawables should use Cairo and gdk_pixbuf_render_threshold_alpha().
  *
  * The pixmap that is created is created for the colormap returned
  * by gdk_rgb_get_colormap(). You normally will want to instead use
  * the actual colormap for a widget, and use
  * gdk_pixbuf_render_pixmap_and_mask_for_colormap().
  *
@@ -164,7 +164,7 @@ gdk_pixbuf_render_pixmap_and_mask (GdkPixbuf  *pixbuf,
 				   int         alpha_threshold)
 {
   gdk_pixbuf_render_pixmap_and_mask_for_colormap (pixbuf,
-						  gdk_rgb_get_colormap (),
+						  gdk_colormap_get_system (),
 						  pixmap_return, mask_return,
 						  alpha_threshold);
 }
@@ -150,7 +150,7 @@ gdk_pixbuf_render_threshold_alpha (GdkPixbuf *pixbuf,
  *
  * The pixmap that is created is created for the colormap returned
- * by gdk_rgb_get_colormap(). You normally will want to instead use
+ * by gdk_colormap_get_system(). You normally will want to instead use
  * the actual colormap for a widget, and use
  * gdk_pixbuf_render_pixmap_and_mask_for_colormap().



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]